<?php

namespace Drupal\custom_robots\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure custom_robots settings for this site.
 */
class SettingsForm extends ConfigFormBase {

  /**
   * Current content of robots.txt file.
   *
   * @var false|string
   */
  protected $file_content;

  /**
   * String that divides default and custom parts of robots.txt file.
   *
   * @var string
   */
  protected $prefix_text;

  /**
   * The default part (provided by Drupal Core repository) of robots.txt file.
   *
   * @var false|string[]
   */
  protected $default_content;

  /**
   * {@inheritdoc}
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->file_content = _custom_robots_get_robots_data();
    $this->prefix_text = custom_robots_get_prefix_text();
    $default_content_array = explode($this->prefix_text, $this->file_content);
    $this->default_content = reset($default_content_array);
    parent::__construct($config_factory);
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'custom_robots_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['custom_robots.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('custom_robots.settings');

    $form['robots_default_wrapper'] = [
      '#type' => 'details',
      '#title' => t('Default robots.txt text'),
      '#description' => t('This data goes along to default Drupal installation.'),
      '#open' => FALSE,
    ];
    // Shows default robots.txt text.
    $form['robots_default_wrapper']['robots_default'] = [
      '#type' => 'markup',
      '#markup' => check_markup($this->default_content),
    ];
    $form['custom_robots_wrapper'] = [
      '#type' => 'fieldset',
      '#title' => t('Extra contents of the robots.txt file'),
      '#description' => t('This data will be appended to the default robots.txt text and even if being overwritten while core update, it will be restored after following cron.'),
      '#collapsible' => FALSE,
    ];
    // Shows custom robots.txt text, appended to the default one.
    $form['custom_robots_wrapper']['custom_robots'] = [
      '#type' => 'textarea',
      '#title' => t('Extra contents of robots.txt'),
      '#description' => t("Here you can add custom strings to robots.txt file. They wouldn't be replaced during core update"),
      '#default_value' => $config->get('custom_robots'),
      '#cols' => 60,
      '#rows' => 20,
      '#wysiwyg' => FALSE,
    ];
    $form['actions'] = [
      '#type' => 'actions',
    ];
    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => t('Submit'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $custom_data = $form_state->getValue('custom_robots');
    $this->config('custom_robots.settings')
      ->set('custom_robots', $custom_data)
      ->save();
    _custom_robots_file_overwrite($custom_data, $this->default_content);

    parent::submitForm($form, $form_state);
  }

}
